Description: احكام,آموزش,مشاوره,خداشناسي,قرآن,معاد,مناظره,تحدي,محكم,متشابه,تفسير,تحریف
Keywords: قرآن,پاسخگویی,مرکز ملی پاسخگویی,کتابخانه,گالری,دین,احکام,نرم افزار,دانلود,فیلم

- ثبت نام
- ذخیره؟

اَلسَّلامُ عَلَیکَ وَ عَلی الَأرواحِ الَّتِی حَلَتْ بِفِنآئِکَ عَلَیکُمْ مِنْی جَمِیعاً سَلامُ اللهِ اَبداً ما بَقَیتُ وَ بَقِیَ الَّلیلِ وَ النَّهارُ یا اَبا عَبدِ اللِه، لَقَدْ عَظُمَتِ الرَّزِیَّةُ وَ جَلَتْ وَ عَظُمَتِ الُمصیبَةُ بِکَ عَلَینْا وَ عَلی جَمیِع اَهْلِ الِأسْلِام

# ثبت نام و عضویت

### اطلاعات اجباری

نام کاربری:

لطفا یک نام کاربری برای خود انتخاب کرده و وارد کنید, شما با این نام در سایت شناخته خواهید شد.

- رمز عبور:
- تکرار رمز عبور:

.لطفا" یک رمز عبور برای نام کاربری خود انتخاب کنید. بخش رمز عبور حساس است هر دو قسمت رمز عبور را صحیح وارد کنید

- آدرس ایمیل:
- تکرار آدرس ایمیل:

يک ايميل معتبر وارد کنيد. براي تکميل ثبت نام (جهت ارسال مطلب و ...) شما بايد بر روي لينک فعال سازي که به ايميل شما ارسال مي شود کلیک کنید .
مهم : ایمیل ثبت نامی نباید در ابتدایش www داشته باشد باید مثلا به این صورت باشد example@yahoo.com نه www.example@yahoo.com

سوال تصادفی:

پایتخت ایران ؟

### اطلاعات بیشتر

تنظیم ساعت:

تمامي زمانهايي كه در سايت نمايش داده ميشوند ميتوانند به راحتي بر مبناي موقعيت جغرافيايي و ساعت محلي شما نمايش داده شود. فقط كافيست تفاوت ساعت محلي خود را با مبناي گرينويچ از ليست زير انتخاب كنيد.

نوع انتخاب این بخش:

همچنین می توانید گزینه مربوط به تغییر ساعت فصلی DST را نسبت به محل سکونت خود مشخص نمایید.( تغییر ساعت شش ماهه اول سال)

دریافت ایمیل...

- دريافت ايميل از سوي مديران سايت

ممکن است هر از گاهي مدير سايت بخواهد ايميلي براي کاربران بصورت گروهي ارسال کند و در آن خبر و يا مطلبي را به اطلاع شما برساند.

استان یا شهر:

استان یا شهر زندگي شما كجاست؟

علاقمندي ها:

شغل:

میزان تحصیلات:

تحصیلات کلاسیک و حوزوی

جنسيت:

بيوگرافي:

جزئياتي مختصر درباره خودتان

## قوانین و اساسنامه

جهت عضویت در انجمن ها باید با قوانین زیر توافق کامل داشته باشید:

=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=

کاربر گرامي

قوانین ثبت نام در سایت و استفاده از مطالب

‌ كانون گفتگوی قرآنی با هدف پاسخ به سوالات و شبهات قراني ، فضايي بسيار صميمي و زمينه‌اي مناسب را براي گفتگوي سالم و سازنده براي شما كاربر گرامي فراهم نموده است. شما نيز با حفظ اين صميميت به طرح سوالات و شبهات قرآني خود در سايت اقدام كنيد .در اين پايگاه سعي مي شود به شبهات و سوالات قرآني شما پاسخ داده شود. بنا بر اين اگر در مواردي كه سوال غير قرآني شما به سايت يا آدرس ديگري ارجاع داده شد،‌ از اين حيث است كه در راستاي فعاليت هاي اين سايت نيست. كاربر عزيز ثبت نام و عضويت شما در كانون گفتگوی قرآنی به اين معناست كه قوانين اين سايت را پذيرفته ايد. پس از مطالعه دقيق اين قوانين ، گزينه "ضمن مطالعه دقیق اساسنامه(آيين نامه) ، با همه موارد موافقم" را تيك بزنيد و مراحل "عضويت" را ادامه بدهيد .

الف ) قوانین کاربری
1.هر کاربر می تواند برای عضویت در کانون، تنها يك نام كاربري ایجاد نماید مگر در موارد خاص که لازم است با اجازه مدیر سایت باشد.
2. تمامي کاربران مي بايست هنگام عضويت در سايت ، از کلمات مناسب جهت استفاده در نام کاربري و پروفايل (مشخصات كاربري) خود استفاده نمايند. در صورت مشاهده کلمات نامناسب در نام کاربری (به تشخيص مديران كانون)، نام كاربري مسدود خواهد شد.
3.تغيير نام كاربري فقط توسط مدير فني سايت فقط در موارد خاص امکان پذیر است . لذا در انتخاب نام کاربری خود دقت نمائید.
4.پس از عضويت، امكان لغو عضويت یا درخواست حذف پستها توسط كاربر وجود نخواهد داشت.
5.گذاشتن لينك هايي كه خلاف قوانين كانون باشد ممنوع است و در صورتي كه كاربري مرتكب اين تخلف شد ، بدون تذكر لينك مربوطه ويرايش يا حذف خواهد شد و کاربر خاطی مشمول قوانین محدودیت کاربری خواهد شد.
6.كانون هيچ مسئولیتی نسبت به ارتباط خصوصی کاربران از طریق سایت را ندارد.
7.توصیه اکید به کاربران میشود که مطالب و سوالات خود را از طریق کارشناسان کانون مطرح نمایند و از ایجاد ارتباط خصوصی ناآگاهانه با دیگران کاربران سایت بالاخص جهت پرسش یا مشاوره خودداری نمایند.
8.محیط انجمن متعلق به همه کاربران است لذا هرگونه تخلف یا اشکال را با کیلک بر لینک گزارش تخلف به پلیس سایت اطلاع دهید.
9.رسيدگي به تخلف کاربران سایت تنها از طریق پلیس سایت امکان پذیر است و هرگونه برخورد شخصی با دیگر کاربران سایت، ممنوع بوده و خلاف قوانین سایت شمرده می شود.
10.حفظ حرمت کاربران وظیفه همگانی بوده از این رو در صورت مشاهده هر گونه مزاحمت ،تمسخر، اعتراض، توهین و بي احترامي به كاربران، مديران یا مسئولان سايت، برای کاربر مربوطه، محدویت کاربری ایجاد خواهد شد.
11.با توجه به طرح سوالات و شبهات فراوان در محیط انجمن با هدف پاسخگوئی، در صورتی که مطالب طرح شده را برای خود مضر تشخیص دادید، از مطالعه آنها بپرهیزید. لازم به ذکر است این انجمن هر گونه مسئولیت شرعی و قانونی را در قبال تاثیر کاربران از مطالعه ناقص و سطحی مطالب مطروحه، از خود سلب می نماید.
12.عضویت در سایت به منزله پذیرفتن قوانین کاربری سایت می باشد و هرگونه تخلف از این قوانین موجب محدودیت کاربری خواهد بود.
13. با توجه به محيط قراني سايت کاربران ملزم هستند از آوا تار٬ امضاء و تصاوير مناسب در پروفايل و آلبوم کاربري خود استفاده نمايند درصورت عدم رعايت موارد فوق ويرايش يا حذف شده و کاربر خاطی مشمول قوانین محدودیت کاربری خواهد شد.
14.ارتباط خصوصی و تبادل هر گونه آدرس، تلفن یا هرنوع اطلاعات شخصی از طریق سایت ممنوع بوده و تخلف از قوانین سایت محسوب می شود.
15.با توجه به اینکه کارشناسان سایت صرفا در محیط های انجمن پاسخگوی سوالات کاربران هستند کاربران می توانند در صورتی که سوال خصوصی داشتند از طریق سایت پرسمان قرآن اقدام به ارسال سوال خود نمایند و همچنین جهت مشاوره بیشتر در مورد سوالات و شبهات مطرح شده در سایت از طریق مرکز ملی پاسخگوئی دینی با تلفن 09640 با کارشناسان مربوطه تماس بگیرند.
ب) قوانين ارسال محتوا:
1.كاربران محترم توجه داشته باشند كه هدف و وظيفه اصلي كانون گفتمان قران پاسخگوئي به شبهات و ارتقاء كيفي اطلاعات ديني ؛ علمي ؛ اخلافي؛فرهنگي و احتماعي مي باشد و لذا مطالب خود را با توجه به اهداف بيان شده ارائه نمايند .
2.کليه موضوعاتي که توسط کاربران ايجاد مي شود به دليل بررسي ازجهت مشابه نداشتن و مطابقت داشتن با اهداف تعريف شده براي تائيد ارسال مي شوند . بديهي ست در صورت عدم تائيد موضوع ٬ دليل عدم تائيد به اطلاع کاربر ارسال کننده رسانده خواهد شد .
3.کاربران سايت مي بايست درهنگام ارسال مطلب در انجمن ها از کلمات مناسب استفاده نمايند. كلمات نامناسب تمام اين موارد را شامل مي شود: توهين به مقدسات ديني،‌ واژه هاي ركيك، سخنان غير شرعي با نامحرم،‌ ايجاد جو بدبيني ، پيام خصوصي هاي آزار دهنده ، توهين و ... .
4.در صورت مشاهده کلمات نامناسب ، نخست به تذكر و ويرايش مطالب اقدام خواهد شد و در صورت ادامه يافتن و بي توجهي به قوانين،‌ امكانات كاربر محدود خواهد شد.
5.با توجه به حضور افراد و کاربران گوناگون در انجمن، مسئولیت ارسال مطالب برعهده خود كاربر بوده ولي مديران حق اصلاح يا حذف مطالب نامربوط را دارند.
6.مديران سايت اجازه دارند ، سوالات و شبهاتي كه به نحوي توهين آميز و نامناسب مطرح مي شوند ، را ويرايش كرده ، یا به طور كامل حذف نمايند.
7.کاربران مي بايست سوالات ، شبهات قرآني، مشکلات و مطالب ارسالی خود ، در يک موضوع مناسب طرح نمايند که با مطلب ارسالی تناسب داشته و از آوردن مطالب شعاری و غیر واقعی اجتناب گردد.
.8 کاربران سوال کنند ملزم به پاسخگويي به سوالات اساتيد پاسخگو هستند و عدم پاسخگويي به منزله قبول پاسخ ارائه شده و اتمام بحث در موضوع مي باشد و موضوع مذکور جمع بندي خواهد شد.
9. كليه مطالب ارسالي كاربران در سايت متعلق به سايت خواهد بود.
10.اگر مطلبي در انجمن یا موضوع مناسب خود قرار نگيرد ، توسط مديران سايت به محل مناسب انتقال داده خواهد شد. و این انتقال، توسط مدیر به ارسال کننده مطلب اطلاع داده خواهد شد.
11.در صورت تکرار درج مطلب در محل نامناسب در انجمن ها، که منجر به ناهماهنگی موضوعی سایت گردد، برای ارسال کننده مطالب از سوی مدیر سایت محدودیتهای کاربری ایجاد خواهد شد.
12.لطفا از ارسال موضوعات تکراري جدا خودداري فرماييد. و از طرح يك سوال يا شبهه در چندين انجمن به شدت بپرهيزيد.
13. کاربران می بایست از مطرح کردن تمامي سوالات كه موضوعات متفاوتي دارند ، در يک ارسال جدا خودداري نموده و مطالب متفاوت خود را در چند تاپیک به صورت جداگانه مطرح نمایند.
14. لازم است عنوان تاپيك مناسب و گوياي موضوع مطرح شده باشد در غير اينصورت مديران مجاز به ويرايش و انتخاب عنوان مناسب براي موضوع ارسالي مي باشند . ‌براي انتخاب موضوع مي‌توانيد از كلمات كليدي سوال خود استفاده كنيد
15.بديهي است اگر مطلبي با عنوان نامناسب ارسال شود، توسط مديران سايت عنوان تاپيك تغيير داده خواهد شد.
16.لازم است اهداف نويسنده تاپيك در همان پست اول واضح و روشن بيان شود تا کاربران به دليل مبهم بودن موضوع با برداشت هاي متفاوت خود به نوشتن مطالبي كه تاپيك رو از هدف مدنظر نويسنده دور مي كند نپردازند.
17.كاربران محترم از ايجاد تاپيك هاي بي هدف و لغو و كه تنها جنبه وقتگذراني داشته باشند تحت عناوين مختلف درد د ل ؛ گله ؛ دلتنگي ؛ هزل وطنزهاي نامناسب......... و امثالهم كه هيچ بار ارزشي ندارند جدأ خود داري نمايند.
18.لطفاً در هنگام پاسخ به سوالات و مطالب دیگران از به کار گيري الفاظ و جملاتي که باعث دلسردي وی شود، یا با حفظ جو صمیمی سایت منافات داشته باشد خودداري فرماييد. هرچند مطلب ارسالی بسيار ابتدايي باشد.
19.درج هر گونه لينك يا ادرس سايت،‌ وبلاگ يا نام كتب و منابع شبهه افكن، یا هرنوع سایت یا موردی که تناسبی با سایت نداشته باشد،‌ ممنوع است. در صورتي كه شبهه يا سوالي نياز به منبع داشت ، اساتيد پاسخگو يا مديران سايت خود منبع مورد نظر را مطالبه خواهند كرد.
20.ازطرح مشكلات خصوصي و محرمانه در محيط عمومي انجمن خودداري نموده و پاسخ موارد مشابه را نیازمند پاسخ خصوصی است ازطریق سایت پرسمان قرآن پیگیری فرمائید.
21.امضا کاربران، نباید شامل موارد ذیل باشد: واژه هاي نامناسب؛ لينك به سايت‌هاي مخالف با سياست‌هاي انجمن؛انجمن های دیگر ، تبليغ محصولات تجاري غير قرآني و عنوان هاي نامناسب و موهن و....
22.سوالات مطرح شده در کانون معمولا حداکثر ظرف سه روز از سوی کارشناسان پاسخگوئی خواهد شد مگر آنكه نياز به بررسي بيشتر داشته باشند.
23.هدف انجمن، پاسخگوئی متقن و دقیق به کاربران است از این رو در دریافت پاسخ تعجیل نکنید و در صورت فوریت با ارسال پيام خصوصي به همکار مدیر سایت راهنمايي بخواهید.
24.اختلاف نظر در پاسخ ها، طبیعی بوده و در صورت مشاهده اختلاف شدید در پاسخهای کارشناسان، این مطلب را با مدیر سایت مطرح نمایید.
25.علی رغم تلاش ما در ایجاد محیط ایمن از ویروس، انجمن مسئول ویروسی نبودن فایلهای ارسالی کاربران نبوده و لذا توصیه می شود پس از دريافت فايل‌ها، حتما آنها را ویروس کشی نمایید. کاربران نيز باید پیش از ارسال فایلهای پیوستی از پاک بودن آنها از ویروسهای مخرب اطمینان حاصل نمایند.
26.کاربران از ارسال مطالب و فایل اعم از عکس ، نرم افزار، فایلهای صوتی و ... خلاف شرع و قوانین سایت خودداري نمايند.در صورتی که کاربری مکررا اقدام به ارسال فایلهای ویروسی یا خلاف قوانین سایت نماید، برای وی محدودیتی کاربری ایجاد خواهد شد.
27.رعایت و حفظ قوانين جمهوري اسلامي و شرع مقدس در این سایت، الزامی بوده و هر گونه مطلب مخالف با آنها، مخالف قوانین سایت شمرده خواهد شد.
28.طرح هرگونه شکایت در مورد حذف یا ویرایش موضوعات و مطالب کاربران و موارد مشابه در انجمن های عمومی ممنوع بوده و این موضوع باید به صورت خصوصی برای مدیر مربوطه ارسال گردد.
29.مدیریت مباحث یک انجمن یا تاپیک در اختیار مدیر آن انجمن بوده و وی در صورت مشاهده انحراف مباحث از موضوع خود می تواند اقدام به جداسازی یا حذف یا ادغام مطالب ارسالی نماید و اعتراض یا پیشنهاد کاربران به این امر، تنها از طریق ارسال پیام خصوصی به مدیر مربوطه یا مدیریت سایت خواهد بود.
30.نقل كليه پاسخ هاي کارشناسان و مطالب کانون به استثنای شبهات بدون درج پاسخ، با لينك منبع،‌ براي همگان مجاز است و نيازي به مجوز كتبي ندارد.

به اميد ساعاتي خوش در كانون گفتگوی قرآنی

ضمن مطالعه دقیق اساسنامه ، با همه موارد موافقم